@@ -12,14 +12,16 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+from wsidicom.image_data import ImageData
+from wsidicom.series import WsiDicomLabels, WsiDicomLevels, WsiDicomOverviews
+
 from .config import settings
 from .graphical_annotations import (Annotation, AnnotationGroup,
-                                    AnnotationInstance, ConceptCode,
-                                    Measurement, Point, PointAnnotationGroup,
-                                    Polygon, PolygonAnnotationGroup, Polyline,
+                                    AnnotationInstance, Measurement, Point,
+                                    PointAnnotationGroup, Polygon,
+                                    PolygonAnnotationGroup, Polyline,
                                     PolylineAnnotationGroup)
 from .instance import WsiDataset, WsiInstance
-from .wsidicom import (ImageData, WsiDicom, WsiDicomLabels, WsiDicomLevels,
-                       WsiDicomOverviews)
+from .wsidicom import WsiDicom
 
-__version__ = '0.4.0'
+__version__ = '0.5.0'
